Feature API
===========

.. toctree::
   :maxdepth: 1

   Feature Package Overview <features_overview>

.. autosummary::
   :toctree: generated/api-features

   eegdash.features.datasets
   eegdash.features.decorators
   eegdash.features.extractors
   eegdash.features.inspect
   eegdash.features.serialization
   eegdash.features.utils
   eegdash.features.feature_bank.complexity
   eegdash.features.feature_bank.connectivity
   eegdash.features.feature_bank.csp
   eegdash.features.feature_bank.dimensionality
   eegdash.features.feature_bank.signal
   eegdash.features.feature_bank.spectral
   eegdash.features.feature_bank.utils
